@@ -63,7 +63,8 @@ class SendGrid(object):
             "stats": {
                 "get": "/apiv2/customer.stats.json"},
             "unsubscribes": {
-                "get": "/api/unsubscribes.get.json"}
+                "get": "/api/unsubscribes.get.json",
+                "add": "/api/unsubscribes.add.json"}
         }
 
     def build_params(self, d=None):
@@ -256,6 +257,9 @@ class SendGrid(object):
     def get_unsubscribes(self):
         return self.call('unsubscribes', 'get')
 
+    def add_unsubscribe(self, email):
+        return self.call('unsubscribes', 'add', dict(email=email))
+
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
                         newsletter_name,  # existing newsletter_name to be cloned
